[![DOI](https://zenodo.org/badge/600053436.svg)](https://zenodo.org/badge/latestdoi/600053436)
![pylint](https://github.com/CHESSComputing/ChessAnalysisPipeline/actions/workflows/pylint-check.yml/badge.svg)
![unittests](https://github.com/CHESSComputing/ChessAnalysisPipeline/actions/workflows/unittests.yml/badge.svg)

# ChessAnalysisPipeline (CHAP)
CHAP is a package that provides a framework for executing data anlaysis pipelines. The package can be found on PyPI and conda-forge.

## Subpackages
There are several subpackages within CHAP that contain specialized items to handle specific types of data processing in the CHAP framework. Dependencies for these subpackages can be found in `CHAP/<subpackage_name>/environment.yml`.

## Documentation
Documentation for the latest version can be found on [this project's github pages site](https://chesscomputing.github.io/ChessAnalysisPipeline/).

## Galaxy
The `galaxy-tools/` directory contains a set of CHAP-based tools for use in the [Galaxy](https://galaxyproject.org) science gateway.
